# -*- coding: utf-8 -*-
"""
Craps Simulator

Mike Hegarty (Github: mhegarty)
Jul 2018
"""

# Import Models
from .models import *

# Purge logs
from .utils import purge_logs
purge_logs()